import { AvailableFontWeights, ItalicsFontWeights } from "../../../types-9c7f268d.js";
/**
 * Pixel size values for each font that we use in the design system.
 *
 * We assert that the values match the guardian type scale in our
 * {@link [unit test suite](./typography.test.ts)}.
 */
declare const pxTextSizes: {
    readonly textSans: {
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
        readonly xxlarge: number;
        readonly xxxlarge: number;
    };
    readonly body: {
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
    };
    readonly headline: {
        readonly xxxsmall: number;
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
    };
    readonly titlepiece: {
        readonly small: number;
        readonly medium: number;
        readonly large: number;
    };
};
/**
 * Relative font sizes, calculated from the pixel sizes above;
 * using the pxToRem method.
 *
 * We assert that the computed rem values match the expected values
 * in our {@link [unit test suite](./typography.test.ts)}.
 *
 * See {@link [pxToRem](../utils/convert-value.ts)} for more details.
 */
declare const remTextSizes: {
    readonly textSans: {
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
        readonly xxlarge: number;
        readonly xxxlarge: number;
    };
    readonly body: {
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
    };
    readonly headline: {
        readonly xxxsmall: number;
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
    };
    readonly titlepiece: {
        readonly small: number;
        readonly medium: number;
        readonly large: number;
    };
};
declare const fonts: {
    readonly titlepiece: string;
    readonly headline: string;
    readonly body: string;
    readonly textSans: string;
};
/**
 * @see https://theguardian.design/2a1e5182b/p/0578f1-typography-presets/b/4704a2
 * @see https://www.figma.com/file/OqhZwB5nboFn33iHLYoc6d/%E2%97%90-Typography?type=design&node-id=384%3A3&t=mYsLeX87mBF2Uw8J-1
 *
 * Relative units ensure users can change their user-agent’s font size
 * and having the line height grow accordingly.
 *
 * We meet the Web Consortium Accessibility Guidelines’
 * success criterion for “Text Spacing” (1.4.12) as these values
 * can be overridden by users.
 *
 * @see https://www.w3.org/WAI/WCAG21/Understanding/text-spacing
 */
declare const lineHeights: {
    readonly tight: 1.15;
    readonly regular: 1.3;
    readonly loose: 1.4;
};
declare const fontWeights: {
    readonly light: 300;
    readonly regular: 400;
    readonly medium: 500;
    readonly bold: 700;
};
declare const availableFontWeights: AvailableFontWeights;
declare const italicsFontWeights: ItalicsFontWeights;
declare const underlineThickness: {
    readonly textSans: {
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
        readonly xxlarge: number;
        readonly xxxlarge: number;
    };
    readonly body: {
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
    };
    readonly headline: {
        readonly xxxsmall: number;
        readonly xxsmall: number;
        readonly xsmall: number;
        readonly small: number;
        readonly medium: number;
        readonly large: number;
        readonly xlarge: number;
    };
    readonly titlepiece: {
        readonly small: number;
        readonly medium: number;
        readonly large: number;
    };
};
declare const textSansSizes: {
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
    readonly xxlarge: number;
    readonly xxxlarge: number;
};
declare const bodySizes: {
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
};
declare const headlineSizes: {
    readonly xxxsmall: number;
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
};
declare const titlepieceSizes: {
    readonly small: number;
    readonly medium: number;
    readonly large: number;
};
declare const remBodySizes: {
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
};
declare const remTitlepieceSizes: {
    readonly small: number;
    readonly medium: number;
    readonly large: number;
};
declare const remHeadlineSizes: {
    readonly xxxsmall: number;
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
};
declare const remTextSansSizes: {
    readonly xxsmall: number;
    readonly xsmall: number;
    readonly small: number;
    readonly medium: number;
    readonly large: number;
    readonly xlarge: number;
    readonly xxlarge: number;
    readonly xxxlarge: number;
};
export { pxTextSizes, remTextSizes, fonts, lineHeights, fontWeights, availableFontWeights, italicsFontWeights, underlineThickness, textSansSizes, bodySizes, headlineSizes, titlepieceSizes, remBodySizes, remTitlepieceSizes, remHeadlineSizes, remTextSansSizes };
